import sys
import os

class Repo:
    '''Repository with boxes'''
    def __init__(self,path,subdirs='',dirlength='',compression=''):
        self.path=path.rstrip(os.sep)
        self.subdirs=subdirs
        self.dirlength=dirlength
        self.compression=compression
        self.boxstate=self.path+os.sep+'boxstate.xml'
        self.boxes={}

    def add(self,box):
        self.boxes[box.id]=box

    def getBoxstate(self):
        return self.boxstate

